@@ -29,9 +29,9 @@
 #     merging support
 #
 # $HeadURL: http://svn.collab.net/repos/svn/branches/1.6.x/contrib/client-side/svnmerge/svnmerge.py $
-# $LastChangedDate: 2008-09-02 17:07:08 +0000 (Tue, 02 Sep 2008) $
-# $LastChangedBy: dustin $
-# $LastChangedRevision: 32857 $
+# $LastChangedDate: 2009-03-30 17:07:07 +0000 (Mon, 30 Mar 2009) $
+# $LastChangedBy: hwright $
+# $LastChangedRevision: 36856 $
 #
 # Requisites:
 # svnmerge.py has been tested with all SVN major versions since 1.1 (both
@@ -155,8 +155,8 @@ def kwextract(s):
     except IndexError:
         return "<unknown>"
 
-__revision__ = kwextract('$Rev: 32857 $')
-__date__ = kwextract('$Date: 2008-09-02 17:07:08 +0000 (Tue, 02 Sep 2008) $')
+__revision__ = kwextract('$Rev: 36856 $')
+__date__ = kwextract('$Date: 2009-03-30 17:07:07 +0000 (Mon, 30 Mar 2009) $')
 
 # Additional options, not (yet?) mapped to command line flags
 default_opts = {
@@ -744,7 +744,12 @@ def set_props(dir, name, props):
     if props:
         _run_propset(dir, name, props)
     else:
-        svn_command('propdel "%s" "%s"' % (name, dir))
+        # Check if NAME exists on DIR before trying to delete it.
+        # As of 1.6 propdel no longer supports deleting a
+        # non-existent property.
+        out = launchsvn('propget "%s" "%s"' % (name, dir))
+        if out:
+            svn_command('propdel "%s" "%s"' % (name, dir))
 
 def set_merge_props(dir, props):
     set_props(dir, opts["prop"], props)
