@@ -43,14 +43,13 @@ try:
   my_getopt = getopt.gnu_getopt
 except AttributeError:
   my_getopt = getopt.getopt
-from urllib import quote as url_encode
-
-# Pretend we have true booleans on older python versions
 try:
-  True
-except:
-  True = 1
-  False = 0
+  # Python >=3.0
+  from urllib.parse import quote as urllib_parse_quote
+except ImportError:
+  # Python <3.0
+  from urllib import quote as urllib_parse_quote
+
 
 # Warnings and errors start with these strings.  They are typically
 # followed by a colon and a space, as in "%s: " ==> "WARNING: ".
@@ -95,9 +94,11 @@ def spam_guard_in_html_block(str):
   return _spam_guard_in_html_block_re.subn(_spam_guard_in_html_block_func,
                                            str)[0]
 
-def html_header(title, page_heading=None):
+def html_header(title, page_heading=None, highlight_targets=False):
   """Write HTML file header.  TITLE and PAGE_HEADING parameters are
-  expected to already by HTML-escaped if needed."""
+  expected to already by HTML-escaped if needed.  If HIGHLIGHT_TARGETS
+is true, then write out a style header that causes anchor targets to be
+surrounded by a red border when they are jumped to."""
   if not page_heading:
     page_heading = title
   s  = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"\n'
@@ -105,6 +106,10 @@ def html_header(title, page_heading=None):
   s += '<html><head>\n'
   s += '<meta http-equiv="Content-Type"'
   s += ' content="text/html; charset=UTF-8" />\n'
+  if highlight_targets:
+    s += '<style type="text/css">\n'
+    s += ':target { border: 2px solid red; }\n'
+    s += '</style>\n'
   s += '<title>%s</title>\n' % title
   s += '</head>\n\n'
   s += '<body style="text-color: black; background-color: white">\n\n'
@@ -155,13 +160,14 @@ class Contributor:
     if not log in logs:
       logs.append(log)
 
+  @staticmethod
   def get(username, real_name, email):
     """If this contributor is already registered, just return it;
     otherwise, register it then return it.  Hint: use parse() to
     generate the arguments."""
     c = None
     for key in username, real_name, email:
-      if key and Contributor.all_contributors.has_key(key):
+      if key and key in Contributor.all_contributors:
         c = Contributor.all_contributors[key]
         break
     # If we didn't get a Contributor, create one now.
@@ -183,7 +189,6 @@ class Contributor:
       Contributor.all_contributors[email]     = c
     # This Contributor has never been in better shape; return it.
     return c
-  get = staticmethod(get)
 
   def score(self):
     """Return a contribution score for this contributor."""
@@ -240,6 +245,7 @@ class Contributor:
     """See LogMessage.__hash__() for why this exists."""
     return self.hash_value
 
+  @staticmethod
   def parse(name):
     """Parse NAME, which can be
 
@@ -277,7 +283,6 @@ class Contributor:
       email = email.replace('{_AT_}', '@')
 
     return username, real_name, email
-  parse = staticmethod(parse)
 
   def canonical_name(self):
     """Return a canonical name for this contributor.  The canonical
@@ -309,7 +314,7 @@ class Contributor:
       retval = ''.join(self.real_name.lower().split(' '))
     if retval is None:
       complain('Unable to construct a canonical name for Contributor.', True)
-    return url_encode(retval, safe="!#$&'()+,;<=>@[]^`{}~")
+    return urllib_parse_quote(retval, safe="!#$&'()+,;<=>@[]^`{}~")
 
   def big_name(self, html=False, html_eo=False):
     """Return as complete a name as possible for this contributor.
@@ -355,11 +360,10 @@ class Contributor:
     this contributor was active."""
     out = open(filename, 'w')
     out.write(html_header(self.big_name(html_eo=True),
-                          self.big_name(html=True)))
+                          self.big_name(html=True), True))
     unique_logs = { }
 
-    sorted_activities = self.activities.keys()
-    sorted_activities.sort()
+    sorted_activities = sorted(self.activities.keys())
 
     out.write('<div class="h2" id="activities" title="activities">\n\n')
     out.write('<table border="1">\n')
@@ -383,7 +387,7 @@ class Contributor:
     out.write('</table>\n\n')
     out.write('</div>\n\n')
 
-    sorted_logs = unique_logs.keys()
+    sorted_logs = list(unique_logs.keys())
     sorted_logs.sort()
     for log in sorted_logs:
       out.write('<hr />\n')
@@ -453,7 +457,7 @@ class LogMessage:
     # Map field names (e.g., "Patch", "Review", "Suggested") onto
     # Field objects.
     self.fields = { }
-    if LogMessage.all_logs.has_key(revision):
+    if revision in LogMessage.all_logs:
       complain("Revision '%s' seen more than once" % revision, True)
     LogMessage.all_logs[revision] = self
     rev_as_number = int(revision[1:])
@@ -539,6 +543,7 @@ def graze(input):
           log = LogMessage(m.group(1), m.group(2), m.group(3))
           num_lines = int(m.group(4))
           just_saw_separator = False
+          saw_patch = False
           line = input.readline()
           # Handle 'svn log -v' by waiting for the blank line.
           while line != '\n':
@@ -554,7 +559,7 @@ def graze(input):
               while m:
                 if not field:
                   ident = m.group(1)
-                  if field_aliases.has_key(ident):
+                  if ident in field_aliases:
                     field = Field(field_aliases[ident], ident)
                   else:
                     field = Field(ident)
@@ -568,8 +573,18 @@ def graze(input):
                   user = log.committer
                 c = Contributor.get(user, real, email)
                 c.add_activity(field.name, log)
+                if (field.name == 'Patch'):
+                  saw_patch = True
                 field.add_contributor(c)
                 line = input.readline()
+                if line == log_separator:
+                  # If the log message doesn't end with its own
+                  # newline (that is, there's the newline added by the
+                  # svn client, but no further newline), then just move
+                  # on to the next log entry.
+                  just_saw_separator = True
+                  num_lines = 0
+                  break
                 log.accum(line)
                 num_lines -= 1
                 m = in_field_re.match(line)
@@ -582,6 +597,9 @@ def graze(input):
                   log.add_field(field)
                   field = None
             num_lines -= 1
+          if not saw_patch and log.committer != '(no author)':
+            c = Contributor.get(log.committer, None, None)
+            c.add_activity('Patch', log)
         continue
 
 index_introduction = '''
@@ -638,10 +656,9 @@ def drop(revision_url_pattern):
   # sort by number of contributions, so the most active people appear at
   # the top -- that way we know whom to look at first for commit access
   # proposals.
-  sorted_contributors = Contributor.all_contributors.values()
-  sorted_contributors.sort()
+  sorted_contributors = sorted(Contributor.all_contributors.values())
   for c in sorted_contributors:
-    if not seen_contributors.has_key(c):
+    if c not in seen_contributors:
       if c.score() > 0:
         if c.is_full_committer:
           # Don't even bother to print out full committers.  They are
@@ -654,7 +671,7 @@ def drop(revision_url_pattern):
           urlpath = "%s/%s.html" % (detail_subdir, c.canonical_name())
           fname = os.path.join(detail_subdir, "%s.html" % c.canonical_name())
           index.write('<li><p><a href="%s">%s</a>&nbsp;[%s]%s</p></li>\n'
-                      % (url_encode(urlpath),
+                      % (urllib_parse_quote(urlpath),
                          c.big_name(html=True),
                          c.score_str(), committerness))
           c.html_out(revision_url_pattern, fname)
@@ -682,7 +699,7 @@ def process_committers(committers):
     if line == 'Committers who have asked to be listed as dormant:\n':
       in_full_committers = True
     elif line.find('@') >= 0:
-      line = line.strip()
+      line = line.lstrip()
       m = matcher.match(line)
       user = m.group(1)
       real_and_email = m.group(2).strip()
@@ -694,26 +711,26 @@ def process_committers(committers):
 
 
 def usage():
-  print 'USAGE: %s [-C COMMITTERS_FILE] < SVN_LOG_OR_LOG-V_OUTPUT' \
-        % os.path.basename(sys.argv[0])
-  print ''
-  print 'Create HTML files in the current directory, rooted at index.html,'
-  print 'in which you can browse to see who contributed what.'
-  print ''
-  print 'The log input should use the contribution-tracking format defined'
-  print 'in http://subversion.tigris.org/hacking.html#crediting.'
-  print ''
-  print 'Options:'
-  print ''
-  print '  -h, -H, -?, --help   Print this usage message and exit'
-  print '  -C FILE              Use FILE as the COMMITTERS file'
-  print '  -U URL               Use URL as a Python interpolation pattern to'
-  print '                       generate URLs to link revisions to some kind'
-  print '                       of web-based viewer (e.g. ViewCVS).  The'
-  print '                       interpolation pattern should contain exactly'
-  print '                       one format specifier, \'%s\', which will be'
-  print '                       replaced with the revision number.'
-  print ''
+  print('USAGE: %s [-C COMMITTERS_FILE] < SVN_LOG_OR_LOG-V_OUTPUT' \
+        % os.path.basename(sys.argv[0]))
+  print('')
+  print('Create HTML files in the current directory, rooted at index.html,')
+  print('in which you can browse to see who contributed what.')
+  print('')
+  print('The log input should use the contribution-tracking format defined')
+  print('in http://subversion.tigris.org/hacking.html#crediting.')
+  print('')
+  print('Options:')
+  print('')
+  print('  -h, -H, -?, --help   Print this usage message and exit')
+  print('  -C FILE              Use FILE as the COMMITTERS file')
+  print('  -U URL               Use URL as a Python interpolation pattern to')
+  print('                       generate URLs to link revisions to some kind')
+  print('                       of web-based viewer (e.g. ViewCVS).  The')
+  print('                       interpolation pattern should contain exactly')
+  print('                       one format specifier, \'%s\', which will be')
+  print('                       replaced with the revision number.')
+  print('')
 
 
 def main():
